[GRASS-SVN] r61071 - in grass/trunk: lib/python/temporal temporal/t.list temporal/t.rast.list temporal/t.rast.mapcalc2 temporal/t.rast.univar temporal/t.rast3d.list temporal/t.rast3d.univar temporal/t.vect.list temporal/t.vect.univar

svn_grass at osgeo.org svn_grass at osgeo.org
Sun Jun 29 16:45:03 PDT 2014


Author: huhabla
Date: 2014-06-29 16:45:03 -0700 (Sun, 29 Jun 2014)
New Revision: 61071

Modified:
   grass/trunk/lib/python/temporal/list_stds.py
   grass/trunk/lib/python/temporal/univar_statistics.py
   grass/trunk/temporal/t.list/t.list.html
   grass/trunk/temporal/t.list/t.list.py
   grass/trunk/temporal/t.rast.list/t.rast.list.html
   grass/trunk/temporal/t.rast.list/t.rast.list.py
   grass/trunk/temporal/t.rast.list/test.t.rast.list.sh
   grass/trunk/temporal/t.rast.mapcalc2/test.t.rast.mapcalc2.sh
   grass/trunk/temporal/t.rast.univar/t.rast.univar.html
   grass/trunk/temporal/t.rast.univar/t.rast.univar.py
   grass/trunk/temporal/t.rast.univar/test.t.rast.univar.sh
   grass/trunk/temporal/t.rast3d.list/t.rast3d.list.html
   grass/trunk/temporal/t.rast3d.list/t.rast3d.list.py
   grass/trunk/temporal/t.rast3d.list/test.t.rast3d.list.sh
   grass/trunk/temporal/t.rast3d.univar/t.rast3d.univar.html
   grass/trunk/temporal/t.rast3d.univar/t.rast3d.univar.py
   grass/trunk/temporal/t.rast3d.univar/test.t.rast3d.univar.sh
   grass/trunk/temporal/t.vect.list/t.vect.list.html
   grass/trunk/temporal/t.vect.list/t.vect.list.py
   grass/trunk/temporal/t.vect.list/test.t.vect.list.layer.sh
   grass/trunk/temporal/t.vect.list/test.t.vect.list.sh
   grass/trunk/temporal/t.vect.univar/t.vect.univar.py
   grass/trunk/temporal/t.vect.univar/test.t.vect.univar.sh
Log:
Fixing suboptimal flag names as described in ticket #2317.
Changed -h flag into -s to suppress column names or -c to print column names


Modified: grass/trunk/lib/python/temporal/list_stds.py
===================================================================
--- grass/trunk/lib/python/temporal/list_stds.py	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/lib/python/temporal/list_stds.py	2014-06-29 23:45:03 UTC (rev 61071)
@@ -105,7 +105,7 @@
         
 ###############################################################################
 
-def list_maps_of_stds(type, input, columns, order, where, separator, method, header, gran=None):
+def list_maps_of_stds(type, input, columns, order, where, separator, method, no_header=False, gran=None):
     """! List the maps of a space time dataset using diffetent methods
 
         @param type The type of the maps raster, raster3d or vector
@@ -127,7 +127,7 @@
                            Gaps can be simply identified as the id is "None"
             - "gran" List map using the granularity of the space time dataset,
                       columns are identical to deltagaps
-        @param header Set True to print column names
+       @param no_header Supress the printing of column names
         @param gran The user defined granule to be used if method=gran is set, in case gran=None the
             granule of the space time dataset is used
     """
@@ -156,7 +156,7 @@
             else:
                 maps = sp.get_registered_maps_as_objects_by_granularity(dbif=dbif)
 
-        if header:
+        if no_header is False:
             string = ""
             string += "%s%s" % ("id", separator)
             string += "%s%s" % ("name", separator)
@@ -235,7 +235,7 @@
 
             elif method == "cols":
                 # Print the column names if requested
-                if header:
+                if no_header is False:
                     output = ""
                     count = 0
 

Modified: grass/trunk/lib/python/temporal/univar_statistics.py
===================================================================
--- grass/trunk/temporal/t.list/t.list.html	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.list/t.list.html	2014-06-29 23:45:03 UTC (rev 61071)
@@ -10,7 +10,6 @@
 be printed for each dataset and the order of the datasets. In addition a SQL WHERE statement can
 be specified to select a subset of the requested datasets.
 
-
 <h2>EXAMPLE</h2>
 
 In this example we will create 3 raster maps and register them first only in the

Modified: grass/trunk/temporal/t.list/t.list.py
===================================================================
--- grass/trunk/temporal/t.list/t.list.py	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.list/t.list.py	2014-06-29 23:45:03 UTC (rev 61071)
@@ -71,7 +71,7 @@
 #%end
 
 #%flag
-#% key: h
+#% key: c
 #% description: Print the column names as first row
 #% guisection: Formatting
 #%end
@@ -92,7 +92,7 @@
     order = options["order"]
     where = options["where"]
     separator = grass.separator(options["separator"])
-    colhead = flags['h']
+    colhead = flags['c']
 
     # Make sure the temporal database exists
     tgis.init()

Modified: grass/trunk/temporal/t.rast.list/t.rast.list.html
===================================================================
--- grass/trunk/temporal/t.rast.list/t.rast.list.html	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast.list/t.rast.list.html	2014-06-29 23:45:03 UTC (rev 61071)
@@ -1,21 +1,166 @@
 <h2>DESCRIPTION</h2>
 
-TBD.
+List time stamped raster map layers that are registered in a space time raster dataset. This module provides
+several options to list map layers and their metadata. Listing of map layer can be ordered by metadata,
+metadata columns can be specified and SQL where conditions can be provided to select a map layer subset
+of the input space time raster dataset. Most of the raster map  specific metadat is available for column selection,
+sorting and SQL where statements.
 
+Using the <b>method</b> option allows the specification of different methods to list map layers.
+Method <i>col</i> is the deafult option and sensitive to the <b>column</b>,<b>order</b>
+and <b>where</b> options. It will simply print user specified metadata columns of one map layer per line.
+The <i>comma</i> method will list the map layer as comma separated list that can be used as input
+for spatial modules.
+To print interval length in days and distance from the begin use method <i>delta</i>. Method
+<i>deltagap</i> will additionally print temporal gaps between map layer. The <i>gran</i>
+method allows the listing of map layer sampled by a user defined <b>granule</b>. As default the granularity
+of the space time raster dataset is used for sampling.
+
+For user defined column separator can be specified with the <b>separator</b> option.
+
 <h2>EXAMPLE</h2>
+This example shows several options that are available for map layers listing.
+<div class="code"><pre>
+g.region s=0 n=80 w=0 e=120 b=0 t=50 res=10 res3=10 -p3
 
-Example for checking which maps were used in a time series operation
-(e.g. <em>t.rast.series perform</em>):
+r.mapcalc expr="map_1 = rand(0, 550)"
+r.mapcalc expr="map_2 = rand(0, 450)"
+r.mapcalc expr="map_3 = rand(0, 320)"
+r.mapcalc expr="map_4 = rand(0, 510)"
+r.mapcalc expr="map_5 = rand(0, 300)"
+r.mapcalc expr="map_6 = rand(0, 650)"
 
-<div class="code"><pre>
-t.rast.list input=precipitation_1950_2013_monthly_mm \
-       where="start_time = datetime(start_time, 'start of year', '0 month')"
- precipitation_monthly_mm_0 soeren 1950-01-01 00:00:00 1950-02-01 00:00:00
- precipitation_monthly_mm_12 soeren 1951-01-01 00:00:00 1951-02-01 00:00:00
- ...
- precipitation_monthly_mm_732 soeren 2011-01-01 00:00:00 2011-02-01 00:00:00
- precipitation_monthly_mm_744 soeren 2012-01-01 00:00:00 2012-02-01 00:00:00
- precipitation_monthly_mm_756 soeren 2013-01-01 00:00:00 2013-02-01 00:00:00
+cat > map_list.txt << EOF
+map_1|2001-01-01|2001-04-01
+map_2|2001-05-01|2001-07-01
+map_3|2001-08-01|2001-10-01
+map_4|2001-11-01|2002-01-01
+map_5|2002-02-01|2002-04-01
+map_6|2002-05-01|2002-07-01
+EOF
+
+t.create type=strds temporaltype=absolute \
+         output=test_strds \
+         title="Test STRDS" \
+         description="Test dataset"
+
+t.register type=rast -i input=test_strds file=map_list.txt
+
+t.rast.list method=comma input=test_strds
+map_1 at PERMANENT,map_2 at PERMANENT,map_3 at PERMANENT,map_4 at PERMANENT,map_5 at PERMANENT,map_6 at PERMANENT
+
+t.rast.list method=col input=test_strds
+map_1|PERMANENT|2001-01-01 00:00:00|2001-04-01 00:00:00
+map_2|PERMANENT|2001-05-01 00:00:00|2001-07-01 00:00:00
+map_3|PERMANENT|2001-08-01 00:00:00|2001-10-01 00:00:00
+map_4|PERMANENT|2001-11-01 00:00:00|2002-01-01 00:00:00
+map_5|PERMANENT|2002-02-01 00:00:00|2002-04-01 00:00:00
+map_6|PERMANENT|2002-05-01 00:00:00|2002-07-01 00:00:00
+
+t.rast.list  method=col input=test_strds columns=name,start_time,min,max
+name|start_time|min|max
+map_1|2001-01-01 00:00:00|0.0|548.0
+map_2|2001-05-01 00:00:00|0.0|445.0
+map_3|2001-08-01 00:00:00|0.0|318.0
+map_4|2001-11-01 00:00:00|0.0|503.0
+map_5|2002-02-01 00:00:00|0.0|296.0
+map_6|2002-05-01 00:00:00|0.0|648.0
+
+t.rast.list  method=col input=test_strds columns=name,start_time,min,max where="max > 500"
+name|start_time|min|max
+map_1|2001-01-01 00:00:00|0.0|548.0
+map_4|2001-11-01 00:00:00|0.0|503.0
+map_6|2002-05-01 00:00:00|0.0|648.0
+
+t.rast.list  method=delta input=test_strds
+id|name|mapset|start_time|end_time|interval_length|distance_from_begin
+map_1 at PERMANENT|map_1|PERMANENT|2001-01-01 00:00:00|2001-04-01 00:00:00|90.0|0.0
+map_2 at PERMANENT|map_2|PERMANENT|2001-05-01 00:00:00|2001-07-01 00:00:00|61.0|120.0
+map_3 at PERMANENT|map_3|PERMANENT|2001-08-01 00:00:00|2001-10-01 00:00:00|61.0|212.0
+map_4 at PERMANENT|map_4|PERMANENT|2001-11-01 00:00:00|2002-01-01 00:00:00|61.0|304.0
+map_5 at PERMANENT|map_5|PERMANENT|2002-02-01 00:00:00|2002-04-01 00:00:00|59.0|396.0
+map_6 at PERMANENT|map_6|PERMANENT|2002-05-01 00:00:00|2002-07-01 00:00:00|61.0|485.0
+
+t.rast.list  method=deltagaps input=test_strds
+id|name|mapset|start_time|end_time|interval_length|distance_from_begin
+map_1 at PERMANENT|map_1|PERMANENT|2001-01-01 00:00:00|2001-04-01 00:00:00|90.0|0.0
+None|None|None|2001-04-01 00:00:00|2001-05-01 00:00:00|30.0|90.0
+map_2 at PERMANENT|map_2|PERMANENT|2001-05-01 00:00:00|2001-07-01 00:00:00|61.0|120.0
+None|None|None|2001-07-01 00:00:00|2001-08-01 00:00:00|31.0|181.0
+map_3 at PERMANENT|map_3|PERMANENT|2001-08-01 00:00:00|2001-10-01 00:00:00|61.0|212.0
+None|None|None|2001-10-01 00:00:00|2001-11-01 00:00:00|31.0|273.0
+map_4 at PERMANENT|map_4|PERMANENT|2001-11-01 00:00:00|2002-01-01 00:00:00|61.0|304.0
+None|None|None|2002-01-01 00:00:00|2002-02-01 00:00:00|31.0|365.0
+map_5 at PERMANENT|map_5|PERMANENT|2002-02-01 00:00:00|2002-04-01 00:00:00|59.0|396.0
+None|None|None|2002-04-01 00:00:00|2002-05-01 00:00:00|30.0|455.0
+map_6 at PERMANENT|map_6|PERMANENT|2002-05-01 00:00:00|2002-07-01 00:00:00|61.0|485.0
+
+t.rast.list  method=gran input=test_strds
+id|name|mapset|start_time|end_time|interval_length|distance_from_begin
+map_1 at PERMANENT|map_1|PERMANENT|2001-01-01 00:00:00|2001-02-01 00:00:00|31.0|0.0
+map_1 at PERMANENT|map_1|PERMANENT|2001-02-01 00:00:00|2001-03-01 00:00:00|28.0|31.0
+map_1 at PERMANENT|map_1|PERMANENT|2001-03-01 00:00:00|2001-04-01 00:00:00|31.0|59.0
+None|None|None|2001-04-01 00:00:00|2001-05-01 00:00:00|30.0|90.0
+map_2 at PERMANENT|map_2|PERMANENT|2001-05-01 00:00:00|2001-06-01 00:00:00|31.0|120.0
+map_2 at PERMANENT|map_2|PERMANENT|2001-06-01 00:00:00|2001-07-01 00:00:00|30.0|151.0
+None|None|None|2001-07-01 00:00:00|2001-08-01 00:00:00|31.0|181.0
+map_3 at PERMANENT|map_3|PERMANENT|2001-08-01 00:00:00|2001-09-01 00:00:00|31.0|212.0
+map_3 at PERMANENT|map_3|PERMANENT|2001-09-01 00:00:00|2001-10-01 00:00:00|30.0|243.0
+None|None|None|2001-10-01 00:00:00|2001-11-01 00:00:00|31.0|273.0
+map_4 at PERMANENT|map_4|PERMANENT|2001-11-01 00:00:00|2001-12-01 00:00:00|30.0|304.0
+map_4 at PERMANENT|map_4|PERMANENT|2001-12-01 00:00:00|2002-01-01 00:00:00|31.0|334.0
+None|None|None|2002-01-01 00:00:00|2002-02-01 00:00:00|31.0|365.0
+map_5 at PERMANENT|map_5|PERMANENT|2002-02-01 00:00:00|2002-03-01 00:00:00|28.0|396.0
+map_5 at PERMANENT|map_5|PERMANENT|2002-03-01 00:00:00|2002-04-01 00:00:00|31.0|424.0
+None|None|None|2002-04-01 00:00:00|2002-05-01 00:00:00|30.0|455.0
+map_6 at PERMANENT|map_6|PERMANENT|2002-05-01 00:00:00|2002-06-01 00:00:00|31.0|485.0
+map_6 at PERMANENT|map_6|PERMANENT|2002-06-01 00:00:00|2002-07-01 00:00:00|30.0|516.0
+
+t.rast.list  method=gran input=test_strds gran="2 months"
+id|name|mapset|start_time|end_time|interval_length|distance_from_begin
+map_1 at PERMANENT|map_1|PERMANENT|2001-01-01 00:00:00|2001-03-01 00:00:00|59.0|0.0
+map_1 at PERMANENT|map_1|PERMANENT|2001-03-01 00:00:00|2001-05-01 00:00:00|61.0|59.0
+map_2 at PERMANENT|map_2|PERMANENT|2001-05-01 00:00:00|2001-07-01 00:00:00|61.0|120.0
+map_3 at PERMANENT|map_3|PERMANENT|2001-07-01 00:00:00|2001-09-01 00:00:00|62.0|181.0
+map_3 at PERMANENT|map_3|PERMANENT|2001-09-01 00:00:00|2001-11-01 00:00:00|61.0|243.0
+map_4 at PERMANENT|map_4|PERMANENT|2001-11-01 00:00:00|2002-01-01 00:00:00|61.0|304.0
+map_5 at PERMANENT|map_5|PERMANENT|2002-01-01 00:00:00|2002-03-01 00:00:00|59.0|365.0
+map_5 at PERMANENT|map_5|PERMANENT|2002-03-01 00:00:00|2002-05-01 00:00:00|61.0|424.0
+map_6 at PERMANENT|map_6|PERMANENT|2002-05-01 00:00:00|2002-07-01 00:00:00|61.0|485.0
+
+t.rast.list  method=gran         input=test_strds gran="18 days"
+id|name|mapset|start_time|end_time|interval_length|distance_from_begin
+map_1 at PERMANENT|map_1|PERMANENT|2001-01-01 00:00:00|2001-01-19 00:00:00|18.0|0.0
+map_1 at PERMANENT|map_1|PERMANENT|2001-01-19 00:00:00|2001-02-06 00:00:00|18.0|18.0
+map_1 at PERMANENT|map_1|PERMANENT|2001-02-06 00:00:00|2001-02-24 00:00:00|18.0|36.0
+map_1 at PERMANENT|map_1|PERMANENT|2001-02-24 00:00:00|2001-03-14 00:00:00|18.0|54.0
+map_1 at PERMANENT|map_1|PERMANENT|2001-03-14 00:00:00|2001-04-01 00:00:00|18.0|72.0
+None|None|None|2001-04-01 00:00:00|2001-04-19 00:00:00|18.0|90.0
+map_2 at PERMANENT|map_2|PERMANENT|2001-04-19 00:00:00|2001-05-07 00:00:00|18.0|108.0
+map_2 at PERMANENT|map_2|PERMANENT|2001-05-07 00:00:00|2001-05-25 00:00:00|18.0|126.0
+map_2 at PERMANENT|map_2|PERMANENT|2001-05-25 00:00:00|2001-06-12 00:00:00|18.0|144.0
+map_2 at PERMANENT|map_2|PERMANENT|2001-06-12 00:00:00|2001-06-30 00:00:00|18.0|162.0
+map_2 at PERMANENT|map_2|PERMANENT|2001-06-30 00:00:00|2001-07-18 00:00:00|18.0|180.0
+map_3 at PERMANENT|map_3|PERMANENT|2001-07-18 00:00:00|2001-08-05 00:00:00|18.0|198.0
+map_3 at PERMANENT|map_3|PERMANENT|2001-08-05 00:00:00|2001-08-23 00:00:00|18.0|216.0
+map_3 at PERMANENT|map_3|PERMANENT|2001-08-23 00:00:00|2001-09-10 00:00:00|18.0|234.0
+map_3 at PERMANENT|map_3|PERMANENT|2001-09-10 00:00:00|2001-09-28 00:00:00|18.0|252.0
+map_3 at PERMANENT|map_3|PERMANENT|2001-09-28 00:00:00|2001-10-16 00:00:00|18.0|270.0
+map_4 at PERMANENT|map_4|PERMANENT|2001-10-16 00:00:00|2001-11-03 00:00:00|18.0|288.0
+map_4 at PERMANENT|map_4|PERMANENT|2001-11-03 00:00:00|2001-11-21 00:00:00|18.0|306.0
+map_4 at PERMANENT|map_4|PERMANENT|2001-11-21 00:00:00|2001-12-09 00:00:00|18.0|324.0
+map_4 at PERMANENT|map_4|PERMANENT|2001-12-09 00:00:00|2001-12-27 00:00:00|18.0|342.0
+map_4 at PERMANENT|map_4|PERMANENT|2001-12-27 00:00:00|2002-01-14 00:00:00|18.0|360.0
+None|None|None|2002-01-14 00:00:00|2002-02-01 00:00:00|18.0|378.0
+map_5 at PERMANENT|map_5|PERMANENT|2002-02-01 00:00:00|2002-02-19 00:00:00|18.0|396.0
+map_5 at PERMANENT|map_5|PERMANENT|2002-02-19 00:00:00|2002-03-09 00:00:00|18.0|414.0
+map_5 at PERMANENT|map_5|PERMANENT|2002-03-09 00:00:00|2002-03-27 00:00:00|18.0|432.0
+map_5 at PERMANENT|map_5|PERMANENT|2002-03-27 00:00:00|2002-04-14 00:00:00|18.0|450.0
+map_6 at PERMANENT|map_6|PERMANENT|2002-04-14 00:00:00|2002-05-02 00:00:00|18.0|468.0
+map_6 at PERMANENT|map_6|PERMANENT|2002-05-02 00:00:00|2002-05-20 00:00:00|18.0|486.0
+map_6 at PERMANENT|map_6|PERMANENT|2002-05-20 00:00:00|2002-06-07 00:00:00|18.0|504.0
+map_6 at PERMANENT|map_6|PERMANENT|2002-06-07 00:00:00|2002-06-25 00:00:00|18.0|522.0
+map_6 at PERMANENT|map_6|PERMANENT|2002-06-25 00:00:00|2002-07-13 00:00:00|18.0|540.0
 </pre></div>
 
 <h2>SEE ALSO</h2>

Modified: grass/trunk/temporal/t.rast.list/t.rast.list.py
===================================================================
--- grass/trunk/temporal/t.rast.list/t.rast.list.py	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast.list/t.rast.list.py	2014-06-29 23:45:03 UTC (rev 61071)
@@ -75,8 +75,8 @@
 #%end
 
 #%flag
-#% key: h
-#% description: Print the column names as first row
+#% key: s
+#% description: Suppress printing of column names
 #% guisection: Formatting
 #%end
 
@@ -96,7 +96,7 @@
     separator = grass.separator(options["separator"])
     method = options["method"]
     granule = options["granule"]
-    header = flags["h"]
+    header = flags["s"]
 
     # Make sure the temporal database exists
     tgis.init()

Modified: grass/trunk/temporal/t.rast.list/test.t.rast.list.sh
===================================================================
--- grass/trunk/temporal/t.rast.list/test.t.rast.list.sh	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast.list/test.t.rast.list.sh	2014-06-29 23:45:03 UTC (rev 61071)
@@ -7,13 +7,15 @@
 # The region setting should work for UTM and LL test locations
 g.region s=0 n=80 w=0 e=120 b=0 t=50 res=10 res3=10 -p3
 
-r.mapcalc --o expr="prec_1 = rand(0, 550)"
-r.mapcalc --o expr="prec_2 = rand(0, 450)"
-r.mapcalc --o expr="prec_3 = rand(0, 320)"
-r.mapcalc --o expr="prec_4 = rand(0, 510)"
-r.mapcalc --o expr="prec_5 = rand(0, 300)"
-r.mapcalc --o expr="prec_6 = rand(0, 650)"
+export GRASS_OVERWRITE=1
 
+r.mapcalc expr="prec_1 = rand(0, 550)"
+r.mapcalc expr="prec_2 = rand(0, 450)"
+r.mapcalc expr="prec_3 = rand(0, 320)"
+r.mapcalc expr="prec_4 = rand(0, 510)"
+r.mapcalc expr="prec_5 = rand(0, 300)"
+r.mapcalc expr="prec_6 = rand(0, 650)"
+
 n1=`g.tempfile pid=1 -d` 
 n2=`g.tempfile pid=2 -d`
 n3=`g.tempfile pid=3 -d`
@@ -65,64 +67,64 @@
 prec_6|2001-06-01|2001-07-01
 EOF
 
-t.create --o type=strds temporaltype=absolute output=precip_abs0 title="A test with input files" descr="A test with input files"
+t.create type=strds temporaltype=absolute output=precip_abs0 title="A test with input files" descr="A test with input files"
 
 # The @test
-t.register type=rast --o -i input=precip_abs0 file="${n1}" start="2001-01-01" increment="1 month"
+t.register type=rast -i input=precip_abs0 file="${n1}" start="2001-01-01" increment="1 month"
 t.rast.list    separator=" | " method=comma     input=precip_abs0
-t.rast.list -h input=precip_abs0
-t.rast.list -h separator=" | " method=cols      input=precip_abs0
-t.rast.list -h separator=" | " method=delta     input=precip_abs0
-t.rast.list -h separator=" | " method=deltagaps input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="2 months"
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="1 day"
+t.rast.list  input=precip_abs0
+t.rast.list  separator=" | " method=cols      input=precip_abs0
+t.rast.list  separator=" | " method=delta     input=precip_abs0
+t.rast.list  separator=" | " method=deltagaps input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="2 months"
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="1 day"
 
-t.register type=rast --o input=precip_abs0 file="${n1}" start="2001-01-01" increment="1 month"
+t.register type=rast input=precip_abs0 file="${n1}" start="2001-01-01" increment="1 month"
 t.rast.list    separator=" | " method=comma     input=precip_abs0
-t.rast.list -h input=precip_abs0
-t.rast.list -h separator=" | " method=cols      input=precip_abs0
-t.rast.list -h separator=" | " method=delta     input=precip_abs0
-t.rast.list -h separator=" | " method=deltagaps input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="2 months"
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="6 days"
+t.rast.list  input=precip_abs0
+t.rast.list  separator=" | " method=cols      input=precip_abs0
+t.rast.list  separator=" | " method=delta     input=precip_abs0
+t.rast.list  separator=" | " method=deltagaps input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="2 months"
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="6 days"
 
-t.register type=rast --o -i input=precip_abs0 file="${n2}" 
+t.register type=rast -i input=precip_abs0 file="${n2}" 
 t.rast.list    separator=" | " method=comma     input=precip_abs0
-t.rast.list -h input=precip_abs0
-t.rast.list -h separator=" | " method=cols      input=precip_abs0
-t.rast.list -h separator=" | " method=delta     input=precip_abs0
-t.rast.list -h separator=" | " method=deltagaps input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="2 months"
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="6 days"
+t.rast.list  input=precip_abs0
+t.rast.list  separator=" | " method=cols      input=precip_abs0
+t.rast.list  separator=" | " method=delta     input=precip_abs0
+t.rast.list  separator=" | " method=deltagaps input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="2 months"
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="6 days"
 
-t.register type=rast --o -i input=precip_abs0 file="${n3}"
+t.register type=rast -i input=precip_abs0 file="${n3}"
 t.rast.list    separator=" | " method=comma     input=precip_abs0
-t.rast.list -h separator=" | " method=delta     input=precip_abs0
-t.rast.list -h separator=" | " method=deltagaps input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="2 months"
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="6 days"
+t.rast.list  separator=" | " method=delta     input=precip_abs0
+t.rast.list  separator=" | " method=deltagaps input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="2 months"
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="6 days"
 
-t.register type=rast --o -i input=precip_abs0 file="${n4}"
+t.register type=rast -i input=precip_abs0 file="${n4}"
 t.rast.list    separator=" | " method=comma     input=precip_abs0
-t.rast.list -h separator=" | " method=delta     input=precip_abs0
-t.rast.list -h separator=" | " method=deltagaps input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="2 months"
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="6 days"
+t.rast.list  separator=" | " method=delta     input=precip_abs0
+t.rast.list  separator=" | " method=deltagaps input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="2 months"
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="6 days"
 
-t.register type=rast --o -i input=precip_abs0 file="${n5}"
+t.register type=rast -i input=precip_abs0 file="${n5}"
 t.rast.list    separator=" | " method=comma     input=precip_abs0
-t.rast.list -h input=precip_abs0
-t.rast.list -h separator=" | " method=cols      input=precip_abs0
-t.rast.list -h separator=" | " method=delta     input=precip_abs0
-t.rast.list -h separator=" | " method=deltagaps input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="8 months"
-t.rast.list -h separator=" | " method=gran      input=precip_abs0 gran="13 days"
+t.rast.list  input=precip_abs0
+t.rast.list  separator=" | " method=cols      input=precip_abs0
+t.rast.list  separator=" | " method=delta     input=precip_abs0
+t.rast.list  separator=" | " method=deltagaps input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="8 months"
+t.rast.list  separator=" | " method=gran      input=precip_abs0 gran="13 days"
 
 t.unregister type=rast maps=prec_1,prec_2,prec_3,prec_4,prec_5,prec_6
 t.remove type=strds input=precip_abs0

Modified: grass/trunk/temporal/t.rast.mapcalc2/test.t.rast.mapcalc2.sh
===================================================================
--- grass/trunk/temporal/t.rast.mapcalc2/test.t.rast.mapcalc2.sh	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast.mapcalc2/test.t.rast.mapcalc2.sh	2014-06-29 23:45:03 UTC (rev 61071)
@@ -10,7 +10,7 @@
 g.region s=0 n=80 w=0 e=120 b=0 t=50 res=10 res3=10 -p3
 
 r.mapcalc expr="a1 = rand(0, 550)"
-r.mapcalc expr="a2 = rand(0, 450)"
+r.mapcalc expr="a2 = if(col() == 2, null(), rand(0, 450))"
 r.mapcalc expr="a3 = rand(0, 320)"
 r.mapcalc expr="a4 = rand(0, 510)"
 r.mapcalc expr="a5 = rand(0, 300)"
@@ -43,5 +43,8 @@
 t.rast.mapcalc2 --v expression="B = A1[-1] + A2[1] " base=b nprocs=5
 t.info type=strds input=B
 
+t.rast.mapcalc2 --v expression="B = if(isnull(A1), (A1[-1] + A1[1])/2.0, A1)" base=b nprocs=5
+t.info type=strds input=B
+
 # @postprocess
 t.remove -rf type=strds input=A1,A2,B

Modified: grass/trunk/temporal/t.rast.univar/t.rast.univar.html
===================================================================
--- grass/trunk/temporal/t.rast.univar/t.rast.univar.html	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast.univar/t.rast.univar.html	2014-06-29 23:45:03 UTC (rev 61071)
@@ -27,41 +27,43 @@
          description="Test dataset with daily precipitation"
 
 t.register -i type=rast input=precipitation_daily \
-           file=map_list.txt start="2012-08-20" increment="1 days"
+           file=map_list.txt start="2012-08-20" increment="1 day"
 
 t.info type=strds input=precipitation_daily
  +-------------------- Space Time Raster Dataset -----------------------------+
  |                                                                            |
  +-------------------- Basic information -------------------------------------+
- | Id: ........................ precipitation_daily at ecad90_sample_tmodules
+ | Id: ........................ precipitation_daily at PERMANENT
  | Name: ...................... precipitation_daily
- | Mapset: .................... ecad90_sample_tmodules
- | Creator: ................... lucadelu
- | Creation time: ............. 2013-11-08 10:38:18.782948
+ | Mapset: .................... PERMANENT
+ | Creator: ................... soeren
  | Temporal type: ............. absolute
+ | Creation time: ............. 2014-06-29 23:08:48.165581
+ | Modification time:.......... 2014-06-29 23:08:52.729316
  | Semantic type:.............. mean
  +-------------------- Absolute time -----------------------------------------+
- | Start time:................. 2012-08-27 00:00:00
- | End time:................... 2012-09-03 00:00:00
+ | Start time:................. 2012-08-20 00:00:00
+ | End time:................... 2012-08-27 00:00:00
  | Granularity:................ 1 day
  | Temporal type of maps:...... interval
  +-------------------- Spatial extent ----------------------------------------+
- | North:...................... 75.5
- | South:...................... 25.25
- | East:.. .................... 75.5
- | West:....................... -40.5
+ | North:...................... 80.0
+ | South:...................... 0.0
+ | East:.. .................... 120.0
+ | West:....................... 0.0
  | Top:........................ 0.0
  | Bottom:..................... 0.0
  +-------------------- Metadata information ----------------------------------+
- | Raster register table:...... precipitation_daily_ecad90_sample_tmodules_raster_register
- | North-South resolution min:. 0.25
- | North-South resolution max:. 0.25
- | East-west resolution min:... 0.25
- | East-west resolution max:... 0.25
+ | Raster register table:...... raster_map_register_3446b4c32e4f4f9fbcc3d0757995b9ec
+ | North-South resolution min:. 10.0
+ | North-South resolution max:. 10.0
+ | East-west resolution min:... 10.0
+ | East-west resolution max:... 10.0
  | Minimum value min:.......... 0.0
  | Minimum value max:.......... 0.0
  | Maximum value min:.......... 9.0
  | Maximum value max:.......... 69.0
+ | Aggregation type:........... None
  | Number of registered maps:.. 7
  |
  | Title:
@@ -69,27 +71,26 @@
  | Description:
  | Test dataset with daily precipitation
  | Command history:
- | # 2013-11-08 10:38:18 
+ | # 2014-06-29 23:08:48 
  | t.create type="strds" temporaltype="absolute"
  |     output="precipitation_daily" title="Daily precipitation"
  |     description="Test dataset with daily precipitation"
- | # 2013-11-08 10:38:26 
+ | # 2014-06-29 23:08:52 
  | t.register -i type="rast" input="precipitation_daily"
- |     file="map_list.txt" start="2012-08-20" increment="1 days"
- |
+ |     file="map_list.txt" start="2012-08-20" increment="1 day"
+ | 
  +----------------------------------------------------------------------------+
 
  
-t.rast.univar -eh precipitation_daily
+t.rast.univar -e precipitation_daily
 id|start|end|mean|min|max|mean_of_abs|stddev|variance|coeff_var|sum|null_cells|cells|first_quartile|median|third_quartile|percentile_90
-map_1 at ecad90_sample_tmodules|2012-08-27 00:00:00|2012-08-28 00:00:00|4.50559701492537|0|9|4.50559701492537|2.87457821791815|8.2631999309295|63.8001625177694|420210|0|93264|2|5|7|9
-map_2 at ecad90_sample_tmodules|2012-08-28 00:00:00|2012-08-29 00:00:00|9.48865585863784|0|19|9.48865585863784|5.7779859624471|33.3851217822358|60.8936191651129|884950|0|93264|4|9|15|18
-map_3 at ecad90_sample_tmodules|2012-08-29 00:00:00|2012-08-30 00:00:00|14.47868416538|0|29|14.47868416538|8.63325210721546|74.5330419467402|59.6273253052818|1350340|0|93264|7|14|22|26
-map_4 at ecad90_sample_tmodules|2012-08-30 00:00:00|2012-08-31 00:00:00|19.4582046663236|0|39|19.4582046663236|11.5783111835479|134.05728986307|59.5034916226703|1814750|0|93264|9|19|29|36
-map_5 at ecad90_sample_tmodules|2012-08-31 00:00:00|2012-09-01 00:00:00|24.4868330759993|0|49|24.4868330759993|14.3850752287166|206.930389335835|58.7461644552805|2283740|0|93264|12|24|37|44
-map_6 at ecad90_sample_tmodules|2012-09-01 00:00:00|2012-09-02 00:00:00|29.4854391833934|0|59|29.4854391833934|17.2796032004376|298.584686764572|58.6038522029873|2749930|0|93264|15|30|44|53
-map_7 at ecad90_sample_tmodules|2012-09-02 00:00:00|2012-09-03 00:00:00|34.4274318064848|0|69|34.4274318064848|20.2238928524934|409.005842109134|58.7435419701681|3210840|0|93264|17|34|52|63
-
+map_1 at PERMANENT|2012-08-27 00:00:00|2012-08-28 00:00:00|4.16666666666667|0|9|4.16666666666667|3.01270458042087|9.07638888888889|72.3049099301009|400|0|96|2|3|7|9
+map_2 at PERMANENT|2012-08-28 00:00:00|2012-08-29 00:00:00|9.58333333333333|0|19|9.58333333333333|6.0736223860962|36.8888888888889|63.3769292462212|920|0|96|3|11|14|18
+map_3 at PERMANENT|2012-08-29 00:00:00|2012-08-30 00:00:00|14.4791666666667|0|29|14.4791666666667|8.78680256438914|77.2078993055555|60.6858306605293|1390|0|96|8|13|22|26
+map_4 at PERMANENT|2012-08-30 00:00:00|2012-08-31 00:00:00|19.1666666666667|0|39|19.1666666666667|11.7132996584604|137.201388888889|61.1128677832717|1840|0|96|9|19|30|35
+map_5 at PERMANENT|2012-08-31 00:00:00|2012-09-01 00:00:00|24.7916666666667|0|48|24.7916666666667|14.2937316292454|204.310763888889|57.655388084351|2380|0|96|13|22.5|39|44
+map_6 at PERMANENT|2012-09-01 00:00:00|2012-09-02 00:00:00|31.0416666666667|0|59|31.0416666666667|17.2885539367011|298.894097222222|55.6946704001108|2980|0|96|17|33|44|54
+map_7 at PERMANENT|2012-09-02 00:00:00|2012-09-03 00:00:00|34.7916666666667|0|69|34.7916666666667|20.8401238933191|434.310763888889|59.8997572981626|3340|0|96|14|36|52|62
 </pre></div>
 
 <h2>SEE ALSO</h2>

Modified: grass/trunk/temporal/t.rast.univar/t.rast.univar.py
===================================================================
--- grass/trunk/temporal/t.rast.univar/t.rast.univar.py	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast.univar/t.rast.univar.py	2014-06-29 23:45:03 UTC (rev 61071)
@@ -39,8 +39,8 @@
 #%end
 
 #%flag
-#% key: h
-#% description: Print the column names as first row
+#% key: s
+#% description: Suppress printing of column names
 #% guisection: Formatting
 #%end
 
@@ -56,14 +56,14 @@
     input = options["input"]
     where = options["where"]
     extended = flags["e"]
-    colhead = flags["h"]
+    no_header = flags["s"]
     separator = grass.separator(options["separator"])
 
     # Make sure the temporal database exists
     tgis.init()
 
     tgis.print_gridded_dataset_univar_statistics(
-        "strds", input, where, extended, colhead, separator)
+        "strds", input, where, extended, no_header, separator)
 
 if __name__ == "__main__":
     options, flags = grass.parser()

Modified: grass/trunk/temporal/t.rast.univar/test.t.rast.univar.sh
===================================================================
--- grass/trunk/temporal/t.rast.univar/test.t.rast.univar.sh	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast.univar/test.t.rast.univar.sh	2014-06-29 23:45:03 UTC (rev 61071)
@@ -5,20 +5,23 @@
 # @preprocess step of this test. 
 # The region setting should work for UTM and LL test locations
 g.region s=0 n=80 w=0 e=120 b=0 t=50 res=10 res3=10 -p3
+
+export GRASS_OVERWRITE=1
+
 # Data generation
-r.mapcalc --o expr="prec_1 = rand(0, 550)"
-r.mapcalc --o expr="prec_2 = rand(0, 450)"
-r.mapcalc --o expr="prec_3 = rand(0, 320)"
-r.mapcalc --o expr="prec_4 = rand(0, 510)"
-r.mapcalc --o expr="prec_5 = rand(0, 300)"
-r.mapcalc --o expr="prec_6 = rand(0, 650)"
+r.mapcalc expr="prec_1 = rand(0, 550)"
+r.mapcalc expr="prec_2 = rand(0, 450)"
+r.mapcalc expr="prec_3 = rand(0, 320)"
+r.mapcalc expr="prec_4 = rand(0, 510)"
+r.mapcalc expr="prec_5 = rand(0, 300)"
+r.mapcalc expr="prec_6 = rand(0, 650)"
 
-t.create --o type=strds temporaltype=absolute output=precip_abs1 title="A test" descr="A test"
+t.create type=strds temporaltype=absolute output=precip_abs1 title="A test" descr="A test"
 t.register type=rast --v -i input=precip_abs1 maps=prec_1,prec_2,prec_3,prec_4,prec_5,prec_6 start="2001-01-15 12:05:45" increment="14 days"
 
 # The first @test
-t.rast.univar -he input=precip_abs1 
+t.rast.univar -e input=precip_abs1 
 
-t.unregister type=rast maps=prec_1,prec_2,prec_3,prec_4,prec_5,prec_6
-t.remove type=strds input=precip_abs1
-g.remove rast=prec_1,prec_2,prec_3,prec_4,prec_5,prec_6
\ No newline at end of file
+t.rast.univar -s input=precip_abs1 
+
+t.remove  -rf type=strds input=precip_abs1

Modified: grass/trunk/temporal/t.rast3d.list/t.rast3d.list.html
===================================================================
--- grass/trunk/temporal/t.rast3d.list/t.rast3d.list.html	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast3d.list/t.rast3d.list.html	2014-06-29 23:45:03 UTC (rev 61071)
@@ -1,6 +1,7 @@
 <h2>DESCRIPTION</h2>
 
-TBD.
+This module provides the same functionality as <a href="t.rast.list.html">t.rast.list</a>, 
+the only difference is the 3d raster map layer metadata. Please refer to the manpage of <a href="t.rast.list.html">t.rast.list</a>.
 
 <h2>SEE ALSO</h2>
 

Modified: grass/trunk/temporal/t.rast3d.list/t.rast3d.list.py
===================================================================
--- grass/trunk/temporal/t.rast3d.list/t.rast3d.list.py	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast3d.list/t.rast3d.list.py	2014-06-29 23:45:03 UTC (rev 61071)
@@ -66,8 +66,8 @@
 #%end
 
 #%flag
-#% key: h
-#% description: Print the column names as first row
+#% key: s
+#% description: Suppress printing of column names
 #% guisection: Formatting
 #%end
 
@@ -86,7 +86,7 @@
     where = options["where"]
     separator = grass.separator(options["separator"])
     method = options["method"]
-    header = flags["h"]
+    header = flags["s"]
 
     # Make sure the temporal database exists
     tgis.init()

Modified: grass/trunk/temporal/t.rast3d.list/test.t.rast3d.list.sh
===================================================================
--- grass/trunk/temporal/t.rast3d.list/test.t.rast3d.list.sh	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast3d.list/test.t.rast3d.list.sh	2014-06-29 23:45:03 UTC (rev 61071)
@@ -6,13 +6,15 @@
 # The region setting should work for UTM and LL test locations
 g.region s=0 n=80 w=0 e=120 b=0 t=50 res=10 res3=10 -p3
 
-r3.mapcalc --o expr="vol_1 = rand(0, 550)"
-r3.mapcalc --o expr="vol_2 = rand(0, 450)"
-r3.mapcalc --o expr="vol_3 = rand(0, 320)"
-r3.mapcalc --o expr="vol_4 = rand(0, 510)"
-r3.mapcalc --o expr="vol_5 = rand(0, 300)"
-r3.mapcalc --o expr="vol_6 = rand(0, 650)"
+export GRASS_OVERWRITE=1
 
+r3.mapcalc expr="vol_1 = rand(0, 550)"
+r3.mapcalc expr="vol_2 = rand(0, 450)"
+r3.mapcalc expr="vol_3 = rand(0, 320)"
+r3.mapcalc expr="vol_4 = rand(0, 510)"
+r3.mapcalc expr="vol_5 = rand(0, 300)"
+r3.mapcalc expr="vol_6 = rand(0, 650)"
+
 n1=`g.tempfile pid=1 -d` 
 n2=`g.tempfile pid=2 -d`
 n3=`g.tempfile pid=3 -d`
@@ -64,43 +66,43 @@
 vol_6|2001-06-01|2001-07-01
 EOF
 
-t.create --o type=str3ds temporaltype=absolute output=volume_abs1 title="A test with input files" descr="A test with input files"
-t.create --o type=str3ds temporaltype=absolute output=volume_abs2 title="A test with input files" descr="A test with input files"
-t.create --o type=str3ds temporaltype=absolute output=volume_abs3 title="A test with input files" descr="A test with input files"
-t.create --o type=str3ds temporaltype=absolute output=volume_abs4 title="A test with input files" descr="A test with input files"
-t.create --o type=str3ds temporaltype=absolute output=volume_abs5 title="A test with input files" descr="A test with input files"
+t.create type=str3ds temporaltype=absolute output=volume_abs1 title="A test with input files" descr="A test with input files"
+t.create type=str3ds temporaltype=absolute output=volume_abs2 title="A test with input files" descr="A test with input files"
+t.create type=str3ds temporaltype=absolute output=volume_abs3 title="A test with input files" descr="A test with input files"
+t.create type=str3ds temporaltype=absolute output=volume_abs4 title="A test with input files" descr="A test with input files"
+t.create type=str3ds temporaltype=absolute output=volume_abs5 title="A test with input files" descr="A test with input files"
 
 # The first @test
 t.register type=rast3d   input=volume_abs1 file="${n1}" start="2001-01-01" increment="1 months"
 t.rast3d.list    separator=" | " method=comma     input=volume_abs1
-t.rast3d.list -h input=volume_abs1
-t.rast3d.list -h separator=" | " method=cols      input=volume_abs1
-t.rast3d.list -h separator=" | " method=delta     input=volume_abs1
-t.rast3d.list -h separator=" | " method=deltagaps input=volume_abs1
+t.rast3d.list input=volume_abs1
+t.rast3d.list separator=" | " method=cols      input=volume_abs1
+t.rast3d.list separator=" | " method=delta     input=volume_abs1
+t.rast3d.list separator=" | " method=deltagaps input=volume_abs1
 
 t.register -i type=rast3d input=volume_abs2 file="${n2}"
 t.rast3d.list    separator=" | " method=comma     input=volume_abs2
-t.rast3d.list -h input=volume_abs2
-t.rast3d.list -h separator=" | " method=cols      input=volume_abs2
-t.rast3d.list -h separator=" | " method=delta     input=volume_abs2
-t.rast3d.list -h separator=" | " method=deltagaps input=volume_abs2
+t.rast3d.list input=volume_abs2
+t.rast3d.list separator=" | " method=cols      input=volume_abs2
+t.rast3d.list separator=" | " method=delta     input=volume_abs2
+t.rast3d.list separator=" | " method=deltagaps input=volume_abs2
 
 t.register -i type=rast3d input=volume_abs3 file="${n3}"
 t.rast3d.list    separator=" | " method=comma     input=volume_abs3
-t.rast3d.list -h separator=" | " method=delta     input=volume_abs3
-t.rast3d.list -h separator=" | " method=deltagaps input=volume_abs3
+t.rast3d.list separator=" | " method=delta     input=volume_abs3
+t.rast3d.list separator=" | " method=deltagaps input=volume_abs3
 
 t.register -i type=rast3d input=volume_abs4 file="${n4}"
 t.rast3d.list    separator=" | " method=comma     input=volume_abs4
-t.rast3d.list -h separator=" | " method=delta     input=volume_abs4
-t.rast3d.list -h separator=" | " method=deltagaps input=volume_abs4
+t.rast3d.list separator=" | " method=delta     input=volume_abs4
+t.rast3d.list separator=" | " method=deltagaps input=volume_abs4
 
 t.register -i type=rast3d input=volume_abs5 file="${n5}"
 t.rast3d.list    separator=" | " method=comma     input=volume_abs5
-t.rast3d.list -h input=volume_abs5
-t.rast3d.list -h separator=" | " method=cols      input=volume_abs5
-t.rast3d.list -h separator=" | " method=delta     input=volume_abs5
-t.rast3d.list -h separator=" | " method=deltagaps input=volume_abs5
+t.rast3d.list input=volume_abs5
+t.rast3d.list separator=" | " method=cols      input=volume_abs5
+t.rast3d.list separator=" | " method=delta     input=volume_abs5
+t.rast3d.list separator=" | " method=deltagaps input=volume_abs5
 
 t.unregister type=rast3d maps=vol_1,vol_2,vol_3,vol_4,vol_5,vol_6
 t.remove type=str3ds input=volume_abs1,volume_abs2,volume_abs3,volume_abs4,volume_abs5

Modified: grass/trunk/temporal/t.rast3d.univar/t.rast3d.univar.html
===================================================================
--- grass/trunk/temporal/t.rast3d.univar/t.rast3d.univar.html	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast3d.univar/t.rast3d.univar.html	2014-06-29 23:45:03 UTC (rev 61071)
@@ -1,10 +1,13 @@
 <h2>DESCRIPTION</h2>
 
-TBD.
+This module provides the same functionality as <a href="t.rast.univar.html">t.rast.list</a>, 
+the only difference is the vector map layer metadata. Please refer to the manpage of <a href="t.rast.univar.html">t.rast.list</a>.
 
+
 <h2>SEE ALSO</h2>
 
 <em>
+<a href="t.rast.univar.html">t.rast.univar</a>,
 <a href="t.create.html">t.create</a>,
 <a href="t.info.html">t.info</a>
 </em>

Modified: grass/trunk/temporal/t.rast3d.univar/t.rast3d.univar.py
===================================================================
--- grass/trunk/temporal/t.rast3d.univar/t.rast3d.univar.py	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast3d.univar/t.rast3d.univar.py	2014-06-29 23:45:03 UTC (rev 61071)
@@ -39,8 +39,8 @@
 #%end
 
 #%flag
-#% key: h
-#% description: Print the column names as first row
+#% key: s
+#% description: Suppress printing of column names
 #% guisection: Formatting
 #%end
 
@@ -56,14 +56,14 @@
     input = options["input"]
     where = options["where"]
     extended = flags["e"]
-    header = flags["h"]
+    no_header = flags["s"]
     separator = grass.separator(options["separator"])
 
     # Make sure the temporal database exists
     tgis.init()
 
     tgis.print_gridded_dataset_univar_statistics(
-        "str3ds", input, where, extended, header, separator)
+        "str3ds", input, where, extended, no_header, separator)
 
 if __name__ == "__main__":
     options, flags = grass.parser()

Modified: grass/trunk/temporal/t.rast3d.univar/test.t.rast3d.univar.sh
===================================================================
--- grass/trunk/temporal/t.rast3d.univar/test.t.rast3d.univar.sh	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.rast3d.univar/test.t.rast3d.univar.sh	2014-06-29 23:45:03 UTC (rev 61071)
@@ -5,22 +5,25 @@
 # @preprocess step of this test. 
 # The region setting should work for UTM and LL test locations
 g.region s=0 n=80 w=0 e=120 b=0 t=50 res=10 res3=10 -p3
+
+export GRASS_OVERWRITE=1
+
 # Data generation
-r3.mapcalc --o expr="prec_1 = rand(0, 550)"
-r3.mapcalc --o expr="prec_2 = rand(0, 450)"
-r3.mapcalc --o expr="prec_3 = rand(0, 320)"
-r3.mapcalc --o expr="prec_4 = rand(0, 510)"
-r3.mapcalc --o expr="prec_5 = rand(0, 300)"
-r3.mapcalc --o expr="prec_6 = rand(0, 650)"
+r3.mapcalc expr="prec_1 = rand(0, 550)"
+r3.mapcalc expr="prec_2 = rand(0, 450)"
+r3.mapcalc expr="prec_3 = rand(0, 320)"
+r3.mapcalc expr="prec_4 = rand(0, 510)"
+r3.mapcalc expr="prec_5 = rand(0, 300)"
+r3.mapcalc expr="prec_6 = rand(0, 650)"
 
-t.create --o type=str3ds temporaltype=absolute output=precip_abs1 title="A test" descr="A test"
+t.create type=str3ds temporaltype=absolute output=precip_abs1 title="A test" descr="A test"
 t.register type=rast3d --v -i input=precip_abs1 maps=prec_1,prec_2,prec_3,prec_4,prec_5,prec_6 start="2001-01-15 12:05:45" increment="14 days"
 t.info type=str3ds input=precip_abs1
 
 # The first @test
-t.rast3d.univar -he input=precip_abs1 
+t.rast3d.univar -e input=precip_abs1 
 
-t.unregister type=rast3d maps=prec_1,prec_2,prec_3,prec_4,prec_5,prec_6
-t.remove type=str3ds input=precip_abs1
-g.remove rast3d=prec_1,prec_2,prec_3,prec_4,prec_5,prec_6
+t.rast3d.univar -s input=precip_abs1 
 
+t.remove -rf type=str3ds input=precip_abs1
+

Modified: grass/trunk/temporal/t.vect.list/t.vect.list.html
===================================================================
--- grass/trunk/temporal/t.vect.list/t.vect.list.html	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.vect.list/t.vect.list.html	2014-06-29 23:45:03 UTC (rev 61071)
@@ -1,6 +1,7 @@
 <h2>DESCRIPTION</h2>
 
-TBD.
+This module provides the same functionality as <a href="t.rast.list.html">t.rast.list</a>, 
+the only difference is the vector map layer metadata. Please refer to the manpage of <a href="t.rast.list.html">t.rast.list</a>.
 
 <h2>SEE ALSO</h2>
 

Modified: grass/trunk/temporal/t.vect.list/t.vect.list.py
===================================================================
--- grass/trunk/temporal/t.vect.list/t.vect.list.py	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.vect.list/t.vect.list.py	2014-06-29 23:45:03 UTC (rev 61071)
@@ -67,8 +67,8 @@
 #%end
 
 #%flag
-#% key: h
-#% description: Print the column names as first row
+#% key: s
+#% description: Suppress printing of column names
 #% guisection: Formatting
 #%end
 
@@ -87,7 +87,7 @@
     where = options["where"]
     separator = grass.separator(options["separator"])
     method = options["method"]
-    header = flags["h"]
+    header = flags["s"]
 
     # Make sure the temporal database exists
     tgis.init()

Modified: grass/trunk/temporal/t.vect.list/test.t.vect.list.layer.sh
===================================================================
--- grass/trunk/temporal/t.vect.list/test.t.vect.list.layer.sh	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.vect.list/test.t.vect.list.layer.sh	2014-06-29 23:45:03 UTC (rev 61071)
@@ -6,15 +6,17 @@
 # The region setting should work for UTM and LL test locations
 g.region s=0 n=80 w=0 e=120 b=0 t=50 res=10 res3=10 -p3
 
-v.random --o -z seed=1 output=soil_orig n=20 zmin=0 zmax=100 column=sand
+export GRASS_OVERWRITE=1
+
+v.random -z seed=1 output=soil_orig n=20 zmin=0 zmax=100 column=sand
 # Adding new layer with categories
-v.category input=soil_orig out=soils option=transfer layer=1,1 --o
-v.category input=soils out=soil_orig option=transfer layer=1,2 --o
-v.category input=soil_orig out=soils option=transfer layer=1,3 --o
-v.category input=soils out=soil_orig option=transfer layer=1,4 --o
-v.category input=soil_orig out=soils option=transfer layer=1,5 --o
-v.category input=soils out=soil_orig option=transfer layer=1,6 --o
-g.copy --o vect=soil_orig,soils
+v.category input=soil_orig out=soils option=transfer layer=1,1
+v.category input=soils out=soil_orig option=transfer layer=1,2
+v.category input=soil_orig out=soils option=transfer layer=1,3
+v.category input=soils out=soil_orig option=transfer layer=1,4
+v.category input=soil_orig out=soils option=transfer layer=1,5
+v.category input=soils out=soil_orig option=transfer layer=1,6
+g.copy vect=soil_orig,soils
 # Creating new tables for each layer
 db.copy from_table=soil_orig to_table=soils_2
 db.copy from_table=soil_orig to_table=soils_3
@@ -78,43 +80,43 @@
 soils:6|2001-06-01|2001-07-01
 EOF
 
-t.create --o type=stvds temporaltype=absolute output=soils_abs1 title="A test with input files" descr="A test with input files"
-t.create --o type=stvds temporaltype=absolute output=soils_abs2 title="A test with input files" descr="A test with input files"
-t.create --o type=stvds temporaltype=absolute output=soils_abs3 title="A test with input files" descr="A test with input files"
-t.create --o type=stvds temporaltype=absolute output=soils_abs4 title="A test with input files" descr="A test with input files"
-t.create --o type=stvds temporaltype=absolute output=soils_abs5 title="A test with input files" descr="A test with input files"
+t.create type=stvds temporaltype=absolute output=soils_abs1 title="A test with input files" descr="A test with input files"
+t.create type=stvds temporaltype=absolute output=soils_abs2 title="A test with input files" descr="A test with input files"
+t.create type=stvds temporaltype=absolute output=soils_abs3 title="A test with input files" descr="A test with input files"
+t.create type=stvds temporaltype=absolute output=soils_abs4 title="A test with input files" descr="A test with input files"
+t.create type=stvds temporaltype=absolute output=soils_abs5 title="A test with input files" descr="A test with input files"
 
 # The first @test
-t.register type=vect --o   input=soils_abs1 file="${n1}" start="2001-01-01" increment="1 months"
+t.register type=vect   input=soils_abs1 file="${n1}" start="2001-01-01" increment="1 months"
 t.vect.list    separator=" | " method=comma     input=soils_abs1
-t.vect.list -h input=soils_abs1
-t.vect.list -h separator=" | " method=cols      input=soils_abs1
-t.vect.list -h separator=" | " method=delta     input=soils_abs1
-t.vect.list -h separator=" | " method=deltagaps input=soils_abs1
+t.vect.list input=soils_abs1
+t.vect.list separator=" | " method=cols      input=soils_abs1
+t.vect.list separator=" | " method=delta     input=soils_abs1
+t.vect.list separator=" | " method=deltagaps input=soils_abs1
 
-t.register type=vect --o -i input=soils_abs2 file="${n2}"
+t.register type=vect -i input=soils_abs2 file="${n2}"
 t.vect.list    separator=" | " method=comma     input=soils_abs2
-t.vect.list -h input=soils_abs2
-t.vect.list -h separator=" | " method=cols      input=soils_abs2
-t.vect.list -h separator=" | " method=delta     input=soils_abs2
-t.vect.list -h separator=" | " method=deltagaps input=soils_abs2
+t.vect.list input=soils_abs2
+t.vect.list separator=" | " method=cols      input=soils_abs2
+t.vect.list separator=" | " method=delta     input=soils_abs2
+t.vect.list separator=" | " method=deltagaps input=soils_abs2
 
-t.register type=vect --o -i input=soils_abs3 file="${n3}"
+t.register type=vect -i input=soils_abs3 file="${n3}"
 t.vect.list    separator=" | " method=comma     input=soils_abs3
-t.vect.list -h separator=" | " method=delta     input=soils_abs3
-t.vect.list -h separator=" | " method=deltagaps input=soils_abs3
+t.vect.list separator=" | " method=delta     input=soils_abs3
+t.vect.list separator=" | " method=deltagaps input=soils_abs3
 
-t.register type=vect --o -i input=soils_abs4 file="${n4}"
+t.register type=vect -i input=soils_abs4 file="${n4}"
 t.vect.list    separator=" | " method=comma     input=soils_abs4
-t.vect.list -h separator=" | " method=delta     input=soils_abs4
-t.vect.list -h separator=" | " method=deltagaps input=soils_abs4
+t.vect.list separator=" | " method=delta     input=soils_abs4
+t.vect.list separator=" | " method=deltagaps input=soils_abs4
 
-t.register type=vect --o -i input=soils_abs5 file="${n5}"
+t.register type=vect -i input=soils_abs5 file="${n5}"
 t.vect.list    separator=" | " method=comma     input=soils_abs5
-t.vect.list -h input=soils_abs5
-t.vect.list -h separator=" | " method=cols      input=soils_abs5
-t.vect.list -h separator=" | " method=delta     input=soils_abs5
-t.vect.list -h separator=" | " method=deltagaps input=soils_abs5
+t.vect.list input=soils_abs5
+t.vect.list separator=" | " method=cols      input=soils_abs5
+t.vect.list separator=" | " method=delta     input=soils_abs5
+t.vect.list separator=" | " method=deltagaps input=soils_abs5
 
 t.unregister type=vect maps=soils:1,soils:2,soils:3,soils:4,soils:5,soils:6
 t.remove type=stvds input=soils_abs1,soils_abs2,soils_abs3,soils_abs4,soils_abs5

Modified: grass/trunk/temporal/t.vect.list/test.t.vect.list.sh
===================================================================
--- grass/trunk/temporal/t.vect.list/test.t.vect.list.sh	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.vect.list/test.t.vect.list.sh	2014-06-29 23:45:03 UTC (rev 61071)
@@ -6,13 +6,15 @@
 # The region setting should work for UTM and LL test locations
 g.region s=0 n=80 w=0 e=120 b=0 t=50 res=10 res3=10 -p3
 
-v.random --o -z output=lidar_1 n=20 zmin=0 zmax=100 column=height
-v.random --o -z output=lidar_2 n=20 zmin=0 zmax=100 column=height
-v.random --o -z output=lidar_3 n=20 zmin=0 zmax=100 column=height
-v.random --o -z output=lidar_4 n=20 zmin=0 zmax=100 column=height
-v.random --o -z output=lidar_5 n=20 zmin=0 zmax=100 column=height
-v.random --o -z output=lidar_6 n=20 zmin=0 zmax=100 column=height
+export GRASS_OVERWRITE=1
 
+v.random -z output=lidar_1 n=20 zmin=0 zmax=100 column=height
+v.random -z output=lidar_2 n=20 zmin=0 zmax=100 column=height
+v.random -z output=lidar_3 n=20 zmin=0 zmax=100 column=height
+v.random -z output=lidar_4 n=20 zmin=0 zmax=100 column=height
+v.random -z output=lidar_5 n=20 zmin=0 zmax=100 column=height
+v.random -z output=lidar_6 n=20 zmin=0 zmax=100 column=height
+
 n1=`g.tempfile pid=1 -d` 
 n2=`g.tempfile pid=2 -d`
 n3=`g.tempfile pid=3 -d`
@@ -64,43 +66,43 @@
 lidar_6|2001-06-01|2001-07-01
 EOF
 
-t.create --o type=stvds temporaltype=absolute output=lidar_abs1 title="A test with input files" descr="A test with input files"
-t.create --o type=stvds temporaltype=absolute output=lidar_abs2 title="A test with input files" descr="A test with input files"
-t.create --o type=stvds temporaltype=absolute output=lidar_abs3 title="A test with input files" descr="A test with input files"
-t.create --o type=stvds temporaltype=absolute output=lidar_abs4 title="A test with input files" descr="A test with input files"
-t.create --o type=stvds temporaltype=absolute output=lidar_abs5 title="A test with input files" descr="A test with input files"
+t.create type=stvds temporaltype=absolute output=lidar_abs1 title="A test with input files" descr="A test with input files"
+t.create type=stvds temporaltype=absolute output=lidar_abs2 title="A test with input files" descr="A test with input files"
+t.create type=stvds temporaltype=absolute output=lidar_abs3 title="A test with input files" descr="A test with input files"
+t.create type=stvds temporaltype=absolute output=lidar_abs4 title="A test with input files" descr="A test with input files"
+t.create type=stvds temporaltype=absolute output=lidar_abs5 title="A test with input files" descr="A test with input files"
 
 # The first @test
-t.register --o type=vect  input=lidar_abs1 file="${n1}" start="2001-01-01" increment="1 months"
+t.register type=vect  input=lidar_abs1 file="${n1}" start="2001-01-01" increment="1 months"
 t.vect.list    separator=" | " method=comma     input=lidar_abs1
-t.vect.list -h input=lidar_abs1
-t.vect.list -h separator=" | " method=cols      input=lidar_abs1
-t.vect.list -h separator=" | " method=delta     input=lidar_abs1
-t.vect.list -h separator=" | " method=deltagaps input=lidar_abs1
+t.vect.list input=lidar_abs1
+t.vect.list separator=" | " method=cols      input=lidar_abs1
+t.vect.list separator=" | " method=delta     input=lidar_abs1
+t.vect.list separator=" | " method=deltagaps input=lidar_abs1
 
-t.register --o type=vect -i input=lidar_abs2 file="${n2}"
+t.register type=vect -i input=lidar_abs2 file="${n2}"
 t.vect.list    separator=" | " method=comma     input=lidar_abs2
-t.vect.list -h input=lidar_abs2
-t.vect.list -h separator=" | " method=cols      input=lidar_abs2
-t.vect.list -h separator=" | " method=delta     input=lidar_abs2
-t.vect.list -h separator=" | " method=deltagaps input=lidar_abs2
+t.vect.list input=lidar_abs2
+t.vect.list separator=" | " method=cols      input=lidar_abs2
+t.vect.list separator=" | " method=delta     input=lidar_abs2
+t.vect.list separator=" | " method=deltagaps input=lidar_abs2
 
-t.register --o type=vect -i input=lidar_abs3 file="${n3}"
+t.register type=vect -i input=lidar_abs3 file="${n3}"
 t.vect.list    separator=" | " method=comma     input=lidar_abs3
-t.vect.list -h separator=" | " method=delta     input=lidar_abs3
-t.vect.list -h separator=" | " method=deltagaps input=lidar_abs3
+t.vect.list separator=" | " method=delta     input=lidar_abs3
+t.vect.list separator=" | " method=deltagaps input=lidar_abs3
 
-t.register --o type=vect -i input=lidar_abs4 file="${n4}"
+t.register type=vect -i input=lidar_abs4 file="${n4}"
 t.vect.list    separator=" | " method=comma     input=lidar_abs4
-t.vect.list -h separator=" | " method=delta     input=lidar_abs4
-t.vect.list -h separator=" | " method=deltagaps input=lidar_abs4
+t.vect.list separator=" | " method=delta     input=lidar_abs4
+t.vect.list separator=" | " method=deltagaps input=lidar_abs4
 
-t.register --o type=vect -i input=lidar_abs5 file="${n5}"
+t.register type=vect -i input=lidar_abs5 file="${n5}"
 t.vect.list    separator=" | " method=comma     input=lidar_abs5
-t.vect.list -h input=lidar_abs5
-t.vect.list -h separator=" | " method=cols      input=lidar_abs5
-t.vect.list -h separator=" | " method=delta     input=lidar_abs5
-t.vect.list -h separator=" | " method=deltagaps input=lidar_abs5
+t.vect.list input=lidar_abs5
+t.vect.list separator=" | " method=cols      input=lidar_abs5
+t.vect.list separator=" | " method=delta     input=lidar_abs5
+t.vect.list separator=" | " method=deltagaps input=lidar_abs5
 
 #t.unregister type=vect maps=lidar_1,lidar_2,lidar_3,lidar_4,lidar_5,lidar_6
 #t.remove type=stvds input=lidar_abs1,lidar_abs2,lidar_abs3,lidar_abs4,lidar_abs5

Modified: grass/trunk/temporal/t.vect.univar/t.vect.univar.py
===================================================================
--- grass/trunk/temporal/t.vect.univar/t.vect.univar.py	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.vect.univar/t.vect.univar.py	2014-06-29 23:45:03 UTC (rev 61071)
@@ -57,8 +57,8 @@
 #%end
 
 #%flag
-#% key: h
-#% description: Print the column names as first row
+#% key: s
+#% description: Suppress printing of column names
 #% guisection: Formatting
 #%end
 
@@ -67,7 +67,6 @@
 
 ############################################################################
 
-
 def main():
 
     # Get the options
@@ -78,7 +77,7 @@
     column = options["column"]
     where = options["where"]
     extended = flags["e"]
-    header = flags["h"]
+    header = flags["s"]
     separator = grass.separator(options["separator"])
 
     # Make sure the temporal database exists

Modified: grass/trunk/temporal/t.vect.univar/test.t.vect.univar.sh
===================================================================
--- grass/trunk/temporal/t.vect.univar/test.t.vect.univar.sh	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/temporal/t.vect.univar/test.t.vect.univar.sh	2014-06-29 23:45:03 UTC (rev 61071)
@@ -5,21 +5,24 @@
 # @preprocess step of this test. 
 # The region setting should work for UTM and LL test locations
 g.region s=0 n=80 w=0 e=120 b=0 t=50 res=10 res3=10 -p3
+
+export GRASS_OVERWRITE=1
+
 # Data generation
-v.random --o -z output=rpoints1 zmin=0 zmax=100 seed=1 column=height n=100 
-v.random --o -z output=rpoints2 zmin=0 zmax=100 seed=2 column=height n=100 
-v.voronoi --o input=rpoints1 output=rvoronoi1
-v.voronoi --o input=rpoints2 output=rvoronoi2
+v.random -z output=rpoints1 zmin=0 zmax=100 seed=1 column=height n=100 
+v.random -z output=rpoints2 zmin=0 zmax=100 seed=2 column=height n=100 
+v.voronoi input=rpoints1 output=rvoronoi1
+v.voronoi input=rpoints2 output=rvoronoi2
 
-t.create --o type=stvds temporaltype=absolute output=random_data title="A test" descr="A test"
+t.create type=stvds temporaltype=absolute output=random_data title="A test" descr="A test"
 t.register type=vect --v -i input=random_data maps=rpoints1,rpoints2,rvoronoi1,rvoronoi2 start="2001-01-15 12:05:45" increment="14 days"
 
 # The first @test
-t.vect.univar -h input=random_data column=height where='height > 50' twhere="start_time > '2000-01-01'" layer=1
-t.vect.univar -he input=random_data column=height where='height > 30' twhere="start_time > '2000-01-01'" layer=1
-t.vect.univar -he type=area input=random_data column=height where='height > 10' twhere="start_time > '2000-01-01'" layer=1
-t.vect.univar -he type=centroid input=random_data column=height where='height > 20' twhere="start_time > '2000-01-01'" layer=1
-t.vect.univar -h type=line input=random_data column=height where='height > 20' twhere="start_time > '2000-01-01'" layer=1
+t.vect.univar input=random_data column=height where='height > 50' twhere="start_time > '2000-01-01'" layer=1
+t.vect.univar -e input=random_data column=height where='height > 30' twhere="start_time > '2000-01-01'" layer=1
+t.vect.univar -e type=area input=random_data column=height where='height > 10' twhere="start_time > '2000-01-01'" layer=1
+t.vect.univar -e type=centroid input=random_data column=height where='height > 20' twhere="start_time > '2000-01-01'" layer=1
+t.vect.univar type=line input=random_data column=height where='height > 20' twhere="start_time > '2000-01-01'" layer=1
 
 # @postprocess
 t.unregister type=vect maps=rpoints1,rpoints2,rvoronoi1,rvoronoi2



More information about the grass-commit mailing list
--- grass/trunk/lib/python/temporal/univar_statistics.py	2014-06-29 18:44:54 UTC (rev 61070)
+++ grass/trunk/lib/python/temporal/univar_statistics.py	2014-06-29 23:45:03 UTC (rev 61071)
@@ -10,7 +10,7 @@
 import grass.temporal as tgis
 
 tgis.print_gridded_dataset_univar_statistics(
     type, input, where, extended, header, fs)
 
 ...
 @endcode
@@ -29,14 +29,14 @@
 
 
 def print_gridded_dataset_univar_statistics(type, input, where, extended,
-                                            header, fs):
+                                            no_header=False, fs="|"):
     """!Print univariate statistics for a space time raster or raster3d dataset
 
        @param type Must be "strds" or "str3ds"
        @param input The name of the space time dataset
        @param where A temporal database where statement
        @param extended If True compute extended statistics
-       @param header   If True print column names as header
+       @param no_header Supress the printing of column names
        @param fs Field separator
     """
 
@@ -54,7 +54,7 @@
         core.fatal(_("Space time %(sp)s dataset <%(i)s> is empty") % {
                      'sp': sp.get_new_map_instance(None).get_type(), 'i': id})
 
-    if header == True:
+    if no_header is False:
         string = ""
         string += "id" + fs + "start" + fs + "end" + fs + "mean" + fs
         string += "min" + fs + "max" + fs
@@ -106,7 +106,7 @@
 
 
 def print_vector_dataset_univar_statistics(input, twhere, layer, type, column,
-                                           where, extended, header, fs):
+                                           where, extended, no_header=False, fs="|"):
     """!Print univariate statistics for a space time vector dataset
 
        @param input The name of the space time dataset
@@ -117,7 +117,7 @@
        @param column The name of the attribute column
        @param where A temporal database where statement
        @param extended If True compute extended statistics
-       @param header   If True print column names as header
+       @param no_header Supress the printing of column names
        @param fs Field separator
     """
 
@@ -150,7 +150,7 @@
                      'sp': sp.get_new_map_instance(None).get_type(), 'i': id})
 
     string = ""
-    if header == True:
+    if no_header is False:
         string += "id" + fs + "start" + fs + "end" + fs + "n" + \
             fs + "nmissing" + fs + "nnull" + fs
         string += "min" + fs + "max" + fs + "range"
@@ -10,7 +10,7 @@
 
 tgis.print_gridded_dataset_univar_statistics(
-    type, input, where, extended, header, fs)
+    type, input, where, extended, no_header, fs)
 
 ...

Modified: grass/trunk/temporal/t.list/t.list.html
===================================================================